@@ -32,8 +32,9 @@ class TestCreateLegacyDriver(unit.BaseTestCase):
             'as_of': 'Liberty',
             'what': 'keystone.catalog.core.Driver',
             'in_favor_of': 'keystone.catalog.core.CatalogDriverV8',
-            'remove_in': 'N',
+            'remove_in': mock.ANY,
         }
         mock_reporter.assert_called_with(mock.ANY, mock.ANY, details)
+        self.assertEqual('N', mock_reporter.call_args[0][2]['remove_in'][0])
 
         self.assertIsInstance(impl, catalog.CatalogDriverV8)
